# Table of Contents

- [tags](<./tags.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Tags](<./Tags.md>)
  - [Introduction](<./Tags/Introduction.md>)
  - [Assigning and Removing Tags from Fact Sheets](<./Tags/Assigning-and-Removing-Tags-from-Fact-Sheets.md>)
  - [Using Tags to Filter Fact Sheets](<./Tags/Using-Tags-to-Filter-Fact-Sheets.md>)
  - [Using Tags as Views in Reports](<./Tags/Using-Tags-as-Views-in-Reports.md>)
  - [Creating and Managing Tag Groups](<./Tags/Creating-and-Managing-Tag-Groups.md>)
  - [Tags v/s Custom Attributes](<./Tags/Tags-vs-Custom-Attributes.md>)
  - [Was this page helpful?](<./Tags/Was-this-page-helpful.md>)
